Module logging

Module logging 

This module is currently a wrapper for the ‘tracing’ crate. The goal is to provide an abstraction so that other modules do not depend on tracing directrly, making it easy to swap our way of logging more easily in the future if needed.