Module mac

Module mac 

This module provides a native Medium Access Control (MAC) address type to eliminate dependency on external network parsing libraries within the core.

It also includes Organizationally Unique Identifier (OUI) database initialization and handling for vendor identification.

Structs

MacAddr
A native, framework-agnostic MAC address representation.

Functions

vendor
Identify the vendor of a MAC address.