#[non_exhaustive]pub enum PortState {
ClosedFiltered,
Filtered,
Unfiltered,
Closed,
OpenFiltered,
Open,
}Expand description
The reachability state of a specific port.
The order of these variants is strictly defined from least definitive to
most definitive. This allows Port::merge() to automatically upgrade
ambiguous states into concrete ones using standard Ord comparisons.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ClosedFiltered
State is ambiguous; port is either closed or filtered (e.g., IP ID idle scan).
Filtered
Packets are being dropped silently by a firewall. We received no response.
Unfiltered
Target is accessible, but we cannot determine if it is open or closed (e.g., TCP ACK scan).
Closed
Actively rejecting connections (e.g., TCP RST received).
OpenFiltered
State is ambiguous; port might be open, or packets might be silently dropped (e.g., UDP scan).
Open
Actively accepting connections (e.g., TCP SYN/ACK received).