pub enum ScriptOutput {
String(String),
Integer(i64),
Float(f64),
Boolean(bool),
List(Vec<ScriptOutput>),
Map(HashMap<String, ScriptOutput>),
}Expand description
Structured data returned by a scanning script or vulnerability engine.
Replaces legacy stringly-typed script outputs, allowing modern engines to return complex nested data (e.g., parsed JSON directories, lists of CVEs).
Variants
String(String)
Integer(i64)
Float(f64)
Boolean(bool)
List(Vec<ScriptOutput>)
Map(HashMap<String, ScriptOutput>)