Extensions for MAC address conversions between pnet and the core domain model.
Traits
- Into
Core Mac - An extension trait to seamlessly convert from
pnet::util::MacAddrto the nativecrate::core::models::mac::MacAddr.
Extensions for MAC address conversions between pnet and the core domain model.
pnet::util::MacAddr to the
native crate::core::models::mac::MacAddr.