Module system

Module system 

Network Interfaces

This module resolves, validates, and routes the network hardware interfaces attached to the host. It provides capabilities like classifying local hardware connections (wired vs wireless), fetching network IPv4 assignments, and routing an arbitrary set of network targets securely out of the host boundaries.

Exposes a clean facade for all interface management logic to consumers.

Modules

interface
Network Interfaces