Functions
- get_
prioritized_ interfaces - Resolves a list of prioritized network interfaces (e.g. wired interfaces first).
- is_
layer_ 2_ capable - Determines if the interface is capable of Layer 2 operations (like ARP).
- is_
on_ link - Validates whether the entire set of targets exists on the exact same layer 2 link as the interface.