is_layer_2_capable

Function is_layer_2_capable 

pub fn is_layer_2_capable(intf: &NetworkInterface) -> bool
Determines if the interface is capable of Layer 2 operations (like ARP).

An interface is capable if it is not point-to-point, not a loopback, and holds a MAC address.