TargetSet

Struct TargetSet 

pub struct TargetSet { /* private fields */ }
A blueprint pairing a set of IP addresses with a set of ports.

TargetSet supports lazy evaluation of the underlying sets. Volume queries and iteration will safely trigger normalization of the IPs and ports.

Implementations

Source

impl TargetSet

pub fn new(ips: IpSet, ports: PortSet) -> Self

Creates a new scan blueprint. Defaults to an uncanonicalized state.

pub fn ips(&self) -> &IpSet

Returns a read-only reference to the underlying IP set.

pub fn ports(&self) -> &PortSet

Returns a read-only reference to the underlying Port set.

pub fn ip_count(&mut self) -> u128

Returns the number of unique IP addresses in this set. Performs lazy normalization.

pub fn port_count(&self) -> usize

Returns the number of unique ports in this set.

pub fn canonicalize(&mut self)

Prepares the internal IP and Port sets for high-performance read-only access.

pub fn total_targets(&mut self) -> Result<u128, TargetError>

Returns the total number of targets. Performs lazy normalization if needed.

Returns a TargetError::CapacityOverflow if the calculation exceeds u128::MAX.

pub fn iter(&mut self) -> impl Iterator<Item = Target> + Send + '_

Creates a lazy iterator over every IP/Port combination. Performs lazy normalization.

This uses Arc internally to prevent O(N) memory allocations when iterating over massive subnets (e.g., /8 or IPv6 ranges).

pub fn total_targets_canonical(&self) -> Result<u128, TargetError>

Thread-safe version of total_targets.

This method is strictly read-only. It returns TargetError::UncanonicalizedState if the sets have not been normalized prior to concurrent access.

pub fn is_empty(&self) -> bool

Returns true if either the IP set or the Port set is completely empty.