Network Interfaces
This module resolves, validates, and routes the network hardware interfaces attached to the host. It provides capabilities like classifying local hardware connections (wired vs wireless), fetching network IPv4 assignments, and routing an arbitrary set of network targets securely out of the host boundaries.
Exposes a clean facade for all interface management logic to consumers.
Re-exports
pub use ext::NetworkInterfaceExtension;pub use lan::ViabilityError;pub use lan::get_lan_network;pub use routing::map_ips_to_interfaces;pub use utils::get_prioritized_interfaces;pub use utils::is_layer_2_capable;pub use utils::is_on_link;