Module utils

Module utils 

Functions

get_prioritized_interfaces
Resolves a list of prioritized network interfaces (e.g. wired interfaces first).
is_layer_2_capable
Determines if the interface is capable of Layer 2 operations (like ARP).
is_on_link
Validates whether the entire set of targets exists on the exact same layer 2 link as the interface.