pub fn is_layer_2_capable(intf: &NetworkInterface) -> boolExpand description
Determines if the interface is capable of Layer 2 operations (like ARP).
An interface is capable if it is not point-to-point, not a loopback, and holds a MAC address.
pub fn is_layer_2_capable(intf: &NetworkInterface) -> boolDetermines if the interface is capable of Layer 2 operations (like ARP).
An interface is capable if it is not point-to-point, not a loopback, and holds a MAC address.